OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "This can usually be fixed by giving the web server write access to the config directory." : "This can usually be fixed by giving the web server write access to the config directory.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it.",
    "See %s" : "See %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory.",
    "Sample configuration detected" : "Sample configuration detected",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php",
    "The page could not be found on the server." : "The page could not be found on the server.",
    "%s email verification" : "%s email verification",
    "Email verification" : "Email verification",
    "Click the following button to confirm your email." : "Click the following button to confirm your email.",
    "Click the following link to confirm your email." : "Click the following link to confirm your email.",
    "Confirm your email" : "Confirm your email",
    "Other activities" : "Other activities",
    "%1$s and %2$s" : "%1$s and %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s and %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s and %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s and %5$s",
    "Enterprise bundle" : "Enterprise bundle",
    "Groupware bundle" : "Groupware bundle",
    "Hub bundle" : "Hub bundle",
    "Social sharing bundle" : "Social sharing bundle",
    "PHP %s or higher is required." : "PHP %s or higher is required.",
    "PHP with a version lower than %s is required." : "PHP with a version lower than %s is required.",
    "%sbit or higher PHP required." : "%sbit or higher PHP required.",
    "The following architectures are supported: %s" : "The following architectures are supported: %s",
    "The following databases are supported: %s" : "The following databases are supported: %s",
    "The command line tool %s could not be found" : "The command line tool %s could not be found",
    "The library %s is not available." : "The library %s is not available.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Library %1$s with a version higher than %2$s is required - available version %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Library %1$s with a version lower than %2$s is required - available version %3$s.",
    "The following platforms are supported: %s" : "The following platforms are supported: %s",
    "Server version %s or higher is required." : "Server version %s or higher is required.",
    "Server version %s or lower is required." : "Server version %s or lower is required.",
    "Wiping of device %s has started" : "Wiping of device %s has started",
    "Wiping of device »%s« has started" : "Wiping of device »%s« has started",
    "»%s« started remote wipe" : "»%s« started remote wipe",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished",
    "Wiping of device %s has finished" : "Wiping of device %s has finished",
    "Wiping of device »%s« has finished" : "Wiping of device »%s« has finished",
    "»%s« finished remote wipe" : "»%s« finished remote wipe",
    "Device or application »%s« has finished the remote wipe process." : "Device or application »%s« has finished the remote wipe process.",
    "Remote wipe started" : "Remote wipe started",
    "A remote wipe was started on device %s" : "A remote wipe was started on device %s",
    "Remote wipe finished" : "Remote wipe finished",
    "The remote wipe on %s has finished" : "The remote wipe on %s has finished",
    "Authentication" : "Authentication",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "Avatar image is not square" : "Avatar image is not square",
    "Files" : "ფაილები",
    "View profile" : "View profile",
    "Local time: %s" : "Local time: %s",
    "today" : "today",
    "tomorrow" : "tomorrow",
    "yesterday" : "yesterday",
    "_in %n day_::_in %n days_" : ["in %n day","in %n days"],
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "next month" : "next month",
    "last month" : "last month",
    "_in %n month_::_in %n months_" : ["in %n month","in %n months"],
    "_%n month ago_::_%n months ago_" : ["%n month ago","%n months ago"],
    "next year" : "next year",
    "last year" : "last year",
    "_in %n year_::_in %n years_" : ["in %n year","in %n years"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_in %n hour_::_in %n hours_" : ["in %n hour","in %n hours"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_in %n minute_::_in %n minutes_" : ["in %n minute","in %n minutes"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "in a few seconds" : "in a few seconds",
    "seconds ago" : "seconds ago",
    "Empty file" : "Empty file",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator.",
    "Dot files are not allowed" : "Dot files are not allowed",
    "File already exists" : "File already exists",
    "Invalid path" : "Invalid path",
    "Failed to create file from template" : "Failed to create file from template",
    "Templates" : "Templates",
    "Filename contains at least one invalid character" : "Filename contains at least one invalid character",
    "Empty filename is not allowed" : "Empty filename is not allowed",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" cannot be installed because appinfo file cannot be read.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" cannot be installed because it is not compatible with this version of the server.",
    "__language_name__" : "ქართული ენა",
    "This is an automatically sent email, please do not reply." : "This is an automatically sent email, please do not reply.",
    "Appearance and accessibility" : "Appearance and accessibility",
    "Apps" : "Apps",
    "Personal settings" : "Personal settings",
    "Administration settings" : "Administration settings",
    "Settings" : "Settings",
    "Log out" : "Log out",
    "Accounts" : "Accounts",
    "Email" : "Email",
    "Mail %s" : "Mail %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "View %s on the fediverse",
    "Phone" : "Phone",
    "Call %s" : "Call %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "View %s on Twitter",
    "Website" : "Website",
    "Visit %s" : "Visit %s",
    "Address" : "Address",
    "Profile picture" : "Profile picture",
    "About" : "About",
    "Display name" : "Display name",
    "Headline" : "Headline",
    "Organization" : "Organization",
    "Role" : "Role",
    "Additional settings" : "Additional settings",
    "Enter the database name for %s" : "Enter the database name for %s",
    "You cannot use dots in the database name %s" : "You cannot use dots in the database name %s",
    "You need to enter details of an existing account." : "You need to enter details of an existing account.",
    "Oracle connection could not be established" : "Oracle connection could not be established",
    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
    "Set an admin password." : "Set an admin password.",
    "Cannot create or write into the data directory %s" : "Cannot create or write into the data directory %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Sharing backend %s not found",
    "Sharing backend for %s not found" : "Sharing backend for %s not found",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Unknown share type" : "Unknown share type",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
    "Files cannot be shared with delete permissions" : "Files cannot be shared with delete permissions",
    "Files cannot be shared with create permissions" : "Files cannot be shared with create permissions",
    "Expiration date is in the past" : "Expiration date is in the past",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Cannot set expiration date more than %n days in the future"],
    "Sharing is only allowed with group members" : "Sharing is only allowed with group members",
    "The requested share does not exist anymore" : "The requested share does not exist anymore",
    "The requested share comes from a disabled user" : "The requested share comes from a disabled user",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "The user was not created because the user limit has been reached. Check your notifications to learn more.",
    "Could not find category \"%s\"" : "Could not find category \"%s\"",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sun." : "Sun.",
    "Mon." : "Mon.",
    "Tue." : "Tue.",
    "Wed." : "Wed.",
    "Thu." : "Thu.",
    "Fri." : "Fri.",
    "Sat." : "Sat.",
    "Su" : "Su",
    "Mo" : "Mo",
    "Tu" : "Tu",
    "We" : "We",
    "Th" : "Th",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "January",
    "February" : "February",
    "March" : "March",
    "April" : "April",
    "May" : "May",
    "June" : "June",
    "July" : "July",
    "August" : "August",
    "September" : "September",
    "October" : "October",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "A valid password must be provided" : "A valid password must be provided",
    "Login canceled by app" : "Login canceled by app",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s",
    "a safe home for all your data" : "a safe home for all your data",
    "Application is not enabled" : "Application is not enabled",
    "Authentication error" : "Authentication error",
    "Token expired. Please reload page." : "Token expired. Please reload page.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No database drivers (sqlite, mysql, or postgresql) installed.",
    "Cannot write into \"config\" directory." : "Cannot write into \"config\" directory.",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "This can usually be fixed by giving the web server write access to the config directory. See %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s",
    "Cannot create \"data\" directory." : "Cannot create \"data\" directory.",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "This can usually be fixed by giving the web server write access to the root directory. See %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Permissions can usually be fixed by giving the web server write access to the root directory. See %s.",
    "Your data directory is not writable." : "Your data directory is not writable.",
    "Setting locale to %s failed." : "Setting locale to %s failed.",
    "Please install one of these locales on your system and restart your web server." : "Please install one of these locales on your system and restart your web server.",
    "PHP module %s not installed." : "PHP module %s not installed.",
    "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Adjusting this setting in php.ini will make Nextcloud run again",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
    "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
    "The required %s config variable is not configured in the config.php file." : "The required %s config variable is not configured in the config.php file.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Please ask your server administrator to check the Nextcloud configuration.",
    "Your data directory must be an absolute path." : "Your data directory must be an absolute path.",
    "Check the value of \"datadirectory\" in your configuration." : "Check the value of \"datadirectory\" in your configuration.",
    "Your data directory is invalid." : "Your data directory is invalid.",
    "Action \"%s\" not supported or implemented." : "Action \"%s\" not supported or implemented.",
    "Authentication failed, wrong token or provider ID given" : "Authentication failed, wrong token or provider ID given",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Parameters missing in order to complete the request. Missing Parameters: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "ID \"%1$s\" already used by cloud federation provider \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Cloud Federation Provider with ID: \"%s\" does not exist.",
    "Could not obtain lock type %d on \"%s\"." : "Could not obtain lock type %d on \"%s\".",
    "Storage unauthorized. %s" : "Storage unauthorized. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Storage connection error. %s",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage connection timeout. %s" : "Storage connection timeout. %s",
    "Images" : "Images",
    "Question" : "Question",
    "Optical character recognition" : "Optical character recognition",
    "Chat" : "Chat",
    "Generates a possible headline for a text." : "Generates a possible headline for a text.",
    "Text" : "Text",
    "Summarize" : "Summarize",
    "Summary" : "Summary",
    "Extract topics" : "Extract topics",
    "Translate" : "Translate",
    "Result" : "Result",
    "Free prompt" : "Free prompt",
    "Runs an arbitrary prompt through the language model." : "Runs an arbitrary prompt through the language model.",
    "Generate headline" : "Generate headline",
    "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
    "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
    "Organisation" : "Organisation",
    "Cannot write into \"apps\" directory." : "Cannot write into \"apps\" directory.",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file.",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini."
},
"nplurals=2; plural=(n!=1);");
